#delimit;
clear all;
set more off;
set varabbrev off;
set mem 1G;

local data_dir "Output";
local out_dir "Figures";


***Figure 12***************************************************************************************************;

local filename "\fig12";
insheet using "`data_dir'\canmex8999_bar.txt";
keep value bin number;
rename value value_std;
rename number number_std;
save temp.dta, replace;

insheet using "`data_dir'\canmex8999_bar_alt.txt", clear;
keep value bin number;
merge 1:1 bin using temp.dta;

local x_axis_text "cumulative fraction of 1989 export value";			 
local y_axis_text "fraction of 1999 export value";
local y_axis_values "0(0.05)0.35";

gen bin1 = bin - 0.035/2;
gen bin2 = bin + 0.035/2;

gen label_y1 = value_std;
gen label_x1 = bin1;
replace label_x1 = label_x1 - 0.015 in 1;
replace label_x1 = label_x1 - 0.003 in 2;
replace label_y1 = label_y1 + 0.01 in 2;
replace label_x1 = label_x1 - 0.005 in 3;
replace label_y1 = label_y1 - 0.005 in 4;
replace label_x1 = label_x1 - 0.003 in 4;
replace label_y1 = label_y1 - 0.006 in 6;
replace label_x1 = label_x1 - 0.003 in 8;
replace label_x1 = label_x1 - 0.003 in 9;

gen label_y2 = value;
gen label_x2 = bin2;
replace label_x2 = label_x2 + 0.005 in 2;
replace label_x2 = label_x2 + 0.005 in 5;
replace label_y2 = label_y2 - 0.005 in 6;
replace label_x2 = label_x2 + 0.005 in 6;

gen x1 = .; replace x1 = 0.7 in 1;
gen y1 = .; replace y1 = 0.30 in 1;
gen x2 = .; replace x2 = 0.61 in 1;
gen y2 = .; replace y2 = 0.13 in 1;
local arrow_1 "(pcarrow y1 x1 y2 x2, mc(black) lc(black))";


gen x3 = .; replace x3 = 0.7 in 1;
gen y3 = .; replace y3 = 0.21 in 1;
gen x4 = .; replace x4 = 0.63 in 1;
gen y4 = .; replace y4 = 0.07 in 1;
local arrow_2 "(pcarrow y3 x3 y4 x4, mc(black) lc(black))";

local text_1 "text(0.30 0.705 `"Baseline sorting"', place(e) size(medium))";
local text_2 "text(0.21 0.705 `"Alternative sorting"', place(e) size(medium))";

****************************************************************************************************************;


*******Figure 13********************************************************************************************;
/*
local filename "\fig13";
insheet using "`data_dir'\mexcan8999_bar.txt";
keep value bin number;
rename value value_std;
rename number number_std;
save temp.dta, replace;

insheet using "`data_dir'\mexcan8999_bar_alt.txt", clear;
keep value bin number;
merge 1:1 bin using temp.dta;

local x_axis_text "cumulative fraction of 1989 export value";			 
local y_axis_text "fraction of 1999 export value";
local y_axis_values "0(0.05)0.35";

gen bin1 = bin - 0.035/2;
gen bin2 = bin + 0.035/2;

gen label_y1 = value_std;
gen label_x1 = bin1;
replace label_x1 = label_x1 - 0.01 in 1;
replace label_y1 = label_y1 + 0.005 in 1;
replace label_x1 = label_x1 - 0.003 in 2;
replace label_y1 = label_y1 + 0.01 in 2;
replace label_x1 = label_x1 - 0.005 in 3;
replace label_y1 = label_y1 - 0.005 in 4;
replace label_x1 = label_x1 - 0.003 in 4;
replace label_y1 = label_y1 - 0.006 in 6;
replace label_y1 = label_y1 + 0.01 in 7;
replace label_x1 = label_x1 - 0.004 in 7;
replace label_x1 = label_x1 - 0.003 in 8;
replace label_x1 = label_x1 - 0.003 in 9;

gen label_y2 = value;
gen label_x2 = bin2;
replace label_y2 = label_y2 + 0.007 in 1;
replace label_x2 = label_x2 + 0.009 in 1;
replace label_y2 = label_y2 - 0.005 in 5;
replace label_y2 = label_y2 - 0.005 in 6;
replace label_y2 = label_y2 + 0.005 in 8;

gen x1 = .; replace x1 = 0.7 in 1;
gen y1 = .; replace y1 = 0.30 in 1;
gen x2 = .; replace x2 = 0.59 in 1;
gen y2 = .; replace y2 = 0.09 in 1;
local arrow_1 "(pcarrow y1 x1 y2 x2, mc(black) lc(black))";


gen x3 = .; replace x3 = 0.7 in 1;
gen y3 = .; replace y3 = 0.23 in 1;
gen x4 = .; replace x4 = 0.62 in 1;
gen y4 = .; replace y4 = 0.075 in 1;
local arrow_2 "(pcarrow y3 x3 y4 x4, mc(black) lc(black))";

local text_1 "text(0.30 0.705 `"Baseline sorting"', place(e) size(medium))";
local text_2 "text(0.23 0.705 `"Alternative sorting"', place(e) size(medium))";
*/
****************************************************************************************************************;
gen y_lab1 = number_std;	
format y_lab1 %3.1f;

gen y_lab2 = number;
format y_lab2 %3.1f;

graph set window fontface "Arial";

graph twoway 	(bar value_std bin1, col(black) barw(0.035) yline(0.1 ,lwidth(0.25 ) lcolor(black)))
				(bar value     bin2, col(none) barw(0.035) )
				(scatter label_y1 label_x1, ms(none) mlabc(black) mla(y_lab1) mlabpos(12) mlabg(1.5) mlabs(small))
				(scatter label_y2 label_x2, ms(none) mlabc(black) mla(y_lab2) mlabpos(12) mlabg(1.5) mlabs(small))
				`arrow_1' `arrow_2'
				,
				`text_1' `text_2'
				leg(off)
				xsize(6)
				ysize(3.5)
				ylab(`y_axis_values',nogrid tp(crossing) format(%3.2f) labsize(medsmall) angle(horizontal) labgap(vsmall))
				xlab(0.1(0.1)1.0,nogrid notick tp(crossing) format(%2.1f) labsize(medsmall) labgap(vsmall))
				xti("`x_axis_text'", margin(top) size(medium))
				yti("`y_axis_text'", margin(right) size(medium))
				plotregion(lstyle(none) margin(sides) color(white))
				graphregion(color(white) 
				
);

graph export `out_dir'`filename'.eps, replace;
erase temp.dta;

